<?php
require('magpierss/rss_fetch.inc');

class TadaLists {

    /**
     * Affiche toutes les listes
     */
    function display() {
        $urls = TadaLists::get_urls();
        
        foreach ($urls as $url) {
            $rss = fetch_rss(rtrim($url));
            list($completed, $added) = TadaLists::get_items($rss->items);
            $link = $rss->channel['link'];

            echo '<h3>'.TadaLists::get_list_title($rss).'</h3><ul>';
            foreach ($added as $title) {
                echo '<li><a href="'.$link.'">'.$title.'</a></li>';
            }
            foreach ($completed as $title) {
                echo '<li><del><a href="'.$link.'">'.$title.'</a></del></li>';
            }
            echo '</ul>';
        }
    }

    /**
     * Renvoie un tableau des urls stockes dans le fichier lists.txt
     */
    function get_urls() {
        return file(dirname(__FILE__) . '/lists.txt');
    }

    /**
     * Met  jour la liste d'url dans le fichier lists.txt
     */
    function set_urls($urls) {
        $filename = dirname(__FILE__).'/lists.txt';

        if (is_writable($filename)) {
            if (!$handle = fopen($filename, 'w')) {
                echo "Cannot open file ($filename)";
                exit;
            }
            $b = FALSE;
            foreach ($urls as $url) {
                $url = ($b ? "\n" : '').rtrim($url);
                if (fwrite($handle, $url) === FALSE) {
                    echo "Cannot write to file ($filename)";
                    exit;
                }
                $b = TRUE;
            }
            fclose($handle);
        } else {
            echo "The file $filename is not writable";
        }
    }

    /**
     * Supprime l'url  la ligne indiqu
     */
    function delete_url($line) {
        $urls = TadaLists::get_urls();
        unset($urls[$line-1]);
        TadaLists::set_urls($urls);
    }

    function insert_url($url) {
        $urls = TadaLists::get_urls();
        $urls[] = $url;
        TadaLists::set_urls($urls);
    }

    /**
     * Renvoie le titre en tout en virant la partie entre parenthse.
     */
    function get_list_title($rss) {
        $t = $rss->channel['title'];
        return substr($t, 0, strrpos($t, '(')-1);
    }
    
    /** 
     * Renvoie le titre de l'item + un boolen.
     * Le boolen est  TRUE si la tache est trmine.
     */
    function parse_item($item) {
        list($etat, $title) = explode(' ', $item['title'], 2);
        return array($title, $etat == 'Completed:');
    }

    /**
     * Renvoie deux tableaux de titres. Le premier tant les titres des items
     * trmins, le second, contenant tous les autres titres.
     */
    function get_items($items) {
        $completed = $added = array();
        
        foreach ($items as $item) {
            list($title, $is_completed) = TadaLists::parse_item($item);
            if ($is_completed) {
                $completed[] = $title;
            } else {
                $added[] = $title;
            }
        }
        return array($completed, $added);
    }
}
?>
